
Welcome to zfit-physics
=======================

zfit-physics is a package that provides physics-related functionality to zfit. It is not a standalone package but requires `zfit <https://zfit.readthedocs.io/en/latest/>`_ to be installed.

It can be installed via pip:

.. code-block:: bash

    pip install zfit-physics

or via conda:

.. code-block:: bash

    conda install -c conda-forge zfit-physics

PDF documentation
-----------------

.. toctree::
    :maxdepth: 2

    api/static/zfit_physics.pdf

Extensions
----------

.. toctree::
    :maxdepth: 1

    api/static/zfit_physics.tfpwa.rst
    api/static/zfit_physics.roofit.rst
